pitchtools.is_symbolic_pitch_range_string
=========================================

.. autofunction:: abjad.tools.pitchtools.is_symbolic_pitch_range_string.is_symbolic_pitch_range_string
   :noindex:
